==> agr-center-infrastructure-3.0.0-CLOUD-20221226.110131-1-sources.jar: com/tydic/dyc/agr/repository/po/AgrMainHisPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.util.Date;

/**
 * 描述：agr_main_his
 * 
 * @author auto_gen
 * @date 2022-10-24 16:03
 **/
@Data
public class AgrMainHisPO implements Serializable {
	private static final long serialVersionUID =  5265342241582105373L;

	/**
	 * 主体历史Id
	 */
	private Long agrMainHisId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	private Date effDateStart;
	private Date effDateEnd;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	private Date expDateStart;
	private Date expDateEnd;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	private Date agrSignTimeStart;
	private Date agrSignTimeEnd;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 编制人名称
	 */
	private String createName;
	/**
	 * 编制人用户名
	 */
	private String createUsername;
	/**
	 * 编制人ID
	 */
	private Long createLoginId;
	/**
	 * 编制时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 编制人单位
	 */
	private Long createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-infrastructure-3.1.1.0-CLOUD-20230415.071313-9-sources.jar: com/tydic/dyc/agr/repository/po/AgrMainHisPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.util.Date;

/**
 * 描述：agr_main_his
 * 
 * @author auto_gen
 * @date 2023-04-10 19:16
 **/
@Data
public class AgrMainHisPO implements Serializable {
	private static final long serialVersionUID =  -7108970090234106249L;

	/**
	 * 主体历史Id
	 */
	private Long agrMainHisId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	private Date effDateStart;
	private Date effDateEnd;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	private Date expDateStart;
	private Date expDateEnd;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	private Date agrSignTimeStart;
	private Date agrSignTimeEnd;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 编制人名称
	 */
	private String createName;
	/**
	 * 编制人用户名
	 */
	private String createUsername;
	/**
	 * 编制人ID
	 */
	private Long createLoginId;
	/**
	 * 编制时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 编制人单位
	 */
	private Long createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 排序
	 */
	private String orderBy;

}
